# Generate lognormal simulated dataset based on means/sd of real data
#
require(plyr)

iso <- read.delim("data/Pasotti.dat", quote="")
if( length(names(iso)) == 8 )
{
  iso <- iso[,-(5:6)]
}

is1 <- na.omit(iso[c(1,2,5,6)])

# Data frame with mean and sd of the original data
isS <- ddply(is1, .(Site,SizeClass), summarise, num=length(unique(d13C)),md13C=mean(d13C),sd13C=sd(d13C),md15N=mean(d15N),sd15N=sd(d15N))

# Auxiliary fun to generate the siml data, if you want to simulate lognormal data
# use rlnorm instead of rnorm
#
hh <- function(x) {
  num=length(unique(x$d13C))
  md13C=mean(x$d13C)
  sd13C=sd(x$d13C)
  md15N=mean(x$d15N)
  sd15N=sd(x$d15N)
  
  data.frame(Site=x$Site,SizeClass=x$SizeClass,FeedingGroup=NA, FamilySpecies=NA,
#             d13C=rnorm(num,md13C,sd13C),d15N=rlnorm(num,log(md15N),log(sd15N)))
              d13C=rnorm(num,md13C,sd13C),d15N=rnorm(num,md15N,sd15N))
}
isG <- ddply(is1, .(Site,SizeClass), hh)

write.table(format(isG, digits=4),"data/PasottiSim.dat",sep="\t",row.names=F,quote=F)

